Changelog
=========

0.0.7 (2018-03-07)
---------------------------------
- Added multiple choice of templates.
- Added unit tests.
- Changed the template "change_form.html"

0.0.6.1 (2018-14-06)
---------------------------------
- Fixed validate parameter.

0.0.6 (2018-10-06)
---------------------------------
- Added the string handlers.
- Added the tags render and makeup.
- Fixed bugs

0.0.4-5 (2018-10-06)
---------------------------------
- Added the static ignoring functionality in the "ignore" tag. Added "hidden" tag
- Fixed bug when getting css and html
- Added the ability to work with the django or jinja tags in the editor

0.0.3 (2018-06-06)
---------------------------------
- Added basic and minimal editor configuration
- Corrected the installation of fields with different configurations

0.0.2 (2018-06-04)
---------------------------------
- Added support for many fields "GrapesJsHtmlField" in the form
